@@ -8,6 +8,7 @@
 
 #include <config.h>
 
+#include <panel-applet.h>
 #include <stdio.h>
 #include <string.h>
 #include <sys/stat.h>
@@ -29,7 +30,6 @@
 #include <net/ppp_defs.h>
 
 #include <gnome.h>
-#include <applet-widget.h>
 
 typedef enum {
 	COLOR_RX = 0,
@@ -59,15 +59,12 @@ extern gint use_ISDN;
 extern gint show_extra_info;
 extern gint status_wait_blink;
 
-extern GtkWidget *applet;
-
 void start_callback_update(void);
 void reset_orientation(void);
 void reset_colors(void);
 
-void property_load(const char *path);
-void property_save(const char *path, gint to_default);
-void property_show(AppletWidget *applet, gpointer data);
+void property_load(PanelApplet *applet);
+void property_show(BonoboUIComponent *uic, gpointer data, const gchar *verbname);
 
 
 
